@@ -343,7 +343,7 @@ SdrPage* SdDrawDocument::AllocPage(bool bMasterPage)
 SvStream& operator << (SvStream& rOut, SdDrawDocument& rDoc)
 {
     // #90477# CharSet eSysSet = ::GetStoreCharSet( osl_getThreadTextEncoding());
-    CharSet eSysSet = GetSOStoreTextEncoding(osl_getThreadTextEncoding(), (sal_uInt16)rOut.GetVersion());
+    CharSet eSysSet = GetSOStoreTextEncoding(osl_getThreadTextEncoding());
 
     /**************************************************************************
     * Aktuelle FileFormat-Versionsnummer
@@ -410,7 +410,7 @@ SvStream& operator << (SvStream& rOut, SdDrawDocument& rDoc)
     rOut << rDoc.bOnlineSpell;
     rOut << rDoc.bHideSpell;
     rOut << rDoc.bPresFullScreen;
-    rOut.WriteByteString( rDoc.aPresPage, eSysSet );
+    rOut.WriteUniOrByteString( rDoc.aPresPage, eSysSet );
     rOut << rDoc.bAnimationAllowed;
 
     UINT16 nDocType = (UINT16) rDoc.eDocType;
@@ -463,7 +463,7 @@ SvStream& operator << (SvStream& rOut, SdDrawDocument& rDoc)
 SvStream& operator >> (SvStream& rIn, SdDrawDocument& rDoc)
 {
     // #90477# CharSet eSysSet = ::GetStoreCharSet( osl_getThreadTextEncoding());
-    CharSet eSysSet = GetSOLoadTextEncoding(osl_getThreadTextEncoding(), (sal_uInt16)rIn.GetVersion());
+    CharSet eSysSet = GetSOLoadTextEncoding(osl_getThreadTextEncoding());
 
     rIn >> (FmFormModel&) rDoc;
     rDoc.GetItemPool().LoadCompleted();
@@ -614,7 +614,7 @@ SvStream& operator >> (SvStream& rIn, SdDrawDocument& rDoc)
 
     if (rDoc.nFileFormatVersion >= 10)
     {
-        rIn.ReadByteString( rDoc.aPresPage, eSysSet );
+        rDoc.aPresPage = rIn.ReadUniOrByteString(eSysSet);
     }
 
     if (rDoc.nFileFormatVersion >= 11)
@@ -882,7 +882,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
     }
 
     // Standardvorlage an der Drawing Engine setzen
-    String aName( SdResId(STR_STANDARD_STYLESHEET_NAME));
+    String aName( SdResId(STR_STANDARD_STYLESHEET_NAME).toString() );
     SfxStyleSheet* pSheet = (SfxStyleSheet*)pStyleSheetPool->
                                     Find(aName, SFX_STYLE_FAMILY_PARA);
     SetDefaultStyleSheet(pSheet);
