@@ -128,8 +128,8 @@ void SvInfoObject::Load( SvPersistStream & rStm )
         rStm.SetError( SVSTREAM_WRONGVERSION );
     else
     {
-        rStm.ReadByteString( aStorName, osl_getThreadTextEncoding() );
-        rStm.ReadByteString( aObjName, osl_getThreadTextEncoding() );
+        aStorName = rStm.ReadUniOrByteString( osl_getThreadTextEncoding() );
+        aObjName = rStm.ReadUniOrByteString( osl_getThreadTextEncoding() );
         if( !aObjName.Len() )
             aObjName = aStorName;
         rStm >> aSvClassName;
@@ -242,16 +242,6 @@ SO2_IMPL_STANDARD_CLASS1_DLL(SvObjectContainer,SvObjectContainerFactory,SvObject
     return NULL;
 }
 
-#ifdef TEST_INVARIANT
-void SvObjectContainer::TestMemberObjRef( BOOL /*bFree*/ )
-{
-}
-
-void SvObjectContainer::TestMemberInvariant( BOOL /*bPrint*/ )
-{
-}
-#endif
-
 SvObjectContainer::SvObjectContainer()
 /*  [Beschreibung]
 
@@ -286,49 +276,6 @@ SO2_IMPL_STANDARD_CLASS1_DLL(SvPersist,SvPersistFactory,SvObjectContainer,
     return NULL;
 }
 
-#ifdef TEST_INVARIANT
-void SvPersist::TestMemberObjRef( BOOL /*bFree*/ )
-{
-    if( pChildList )
-    {
-        ULONG nCount = pChildList->Count();
-        for( ULONG i = 0; i < nCount; i++ )
-        {
-            SvInfoObject * pEle = pChildList->GetObject( i );
-            if( pEle->GetObj() )
-            {
-                ByteString aTest( "\t\tpChildList[ " );
-                aTest += ByteString_CreateFromInt32( i );
-                aTest += " ] == ";
-                aTest += ByteString_CreateFromInt32( (ULONG)pEle->GetObj() );
-                OSL_TRACE( "%s", aTest.GetBuffer() );
-            }
-        }
-    }
-    if( aStorage.Is() )
-    {
-        ByteString aTest( "\t\taStorage == " );
-        aTest += ByteString_CreateFromInt32( (ULONG)&aStorage );
-        OSL_TRACE( "%s", aTest.GetBuffer() );
-    }
-}
-
-void SvPersist::TestMemberInvariant( BOOL /*bPrint*/ )
-{
-#ifdef DBG_UTIL
-    DBG_ASSERT( !(bOpSave || bOpSaveAs), "bOpSave && bOpSaveAs" );
-    if( !bIsInit )
-    {
-        if ( !bCreateTempStor )
-        {
-            DBG_ASSERT( bOpHandsOff && !aStorage.Is(), "failed: bOpHandsOff && !aStorage.Is()" );
-            DBG_ASSERT( !bOpHandsOff && aStorage.Is(), "failed: !bOpHandsOff && aStorage.Is()" );
-        }
-    }
-#endif
-}
-#endif
-
 SvPersist::SvPersist()
     : bIsModified     ( FALSE )
     , bIsInit         ( FALSE )
